package com.template.services;

import com.template.model.pojo.AlumniHeart;
import com.template.model.pojo.AlumniHeart;
import com.baomidou.mybatisplus.extension.service.IService;
import com.template.model.result.PageUtils;

import java.util.List;

/**
 * <p>
 *  服务类
 * </p>
 *
 * @author ceshi
 * @since 2025-01-13
 */
public interface AlumniHeartService extends IService<AlumniHeart> {
    int insertAlumniHeart(AlumniHeart au);

    int updateAlumniHeart(AlumniHeart au);

    int deleteDataById(Integer id);

    AlumniHeart queryDataById(Integer id);

    List<AlumniHeart> findTopHearts();

    PageUtils<AlumniHeart> queryPageList(int currentPage, int pageCount, String name, String startTime, String endTime);
}
